pub struct DecommissionPlan {
pub node_id: u64,
pub entries: Vec<MetadataEntry>,
}Expand description
Output of plan_full_decommission — the caller proposes
entries in order, waiting for each to commit before moving on.
Fields
node_id: u64entries: Vec<MetadataEntry>Trait Implementations
Sourceimpl Clone for DecommissionPlan
impl Clone for DecommissionPlan
Sourcefn clone(&self) -> DecommissionPlan
fn clone(&self) -> DecommissionPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecommissionPlan
impl Debug for DecommissionPlan
Sourceimpl PartialEq for DecommissionPlan
impl PartialEq for DecommissionPlan
Sourcefn eq(&self, other: &DecommissionPlan) -> bool
fn eq(&self, other: &DecommissionPlan) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DecommissionPlan
impl StructuralPartialEq for DecommissionPlan