pub struct ArrayShardSliceResp {
pub shard_id: u32,
pub rows_msgpack: Vec<Vec<u8>>,
pub truncated: bool,
pub truncated_before_horizon: bool,
}Expand description
Gather response: shard returns matching rows as opaque msgpack row bytes.
Fields
shard_id: u32rows_msgpack: Vec<Vec<u8>>Zerompk-encoded rows. Each element is a zerompk encoding of one result row.
truncated: boolTrue when the shard hit the limit and may have more rows.
truncated_before_horizon: boolTrue when system_as_of is below the oldest tile version on this shard
and the shard produced zero rows as a result of that horizon.