pub struct ShardSpatialExtent {
pub shard_id: u32,
pub extent: Option<BoundingBox>,
pub entry_count: usize,
}Expand description
Per-shard spatial extent for a collection.
Fields
shard_id: u32extent: Option<BoundingBox>Bounding box covering all geometries in this shard for this collection. None if the shard has no spatial data for this collection.
entry_count: usizeNumber of spatial entries on this shard.