pub struct JoinResponse {
pub success: bool,
pub error: String,
pub cluster_id: u64,
pub nodes: Vec<JoinNodeInfo>,
pub vshard_to_group: Vec<u64>,
pub groups: Vec<JoinGroupInfo>,
}Expand description
Response to a join request — carries full cluster state.
Fields
success: boolerror: Stringcluster_id: u64nodes: Vec<JoinNodeInfo>vshard_to_group: Vec<u64>groups: Vec<JoinGroupInfo>Trait Implementations
Sourceimpl Archive for JoinResponse
impl Archive for JoinResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedJoinResponse
type Archived = ArchivedJoinResponse
The archived representation of this type. Read more
Sourcetype Resolver = JoinResponseResolver
type Resolver = JoinResponseResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for JoinResponse
impl Clone for JoinResponse
Sourcefn clone(&self) -> JoinResponse
fn clone(&self) -> JoinResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JoinResponse
impl Debug for JoinResponse
Sourceimpl<__D: Fallible + ?Sized> Deserialize<JoinResponse, __D> for Archived<JoinResponse>where
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Vec<JoinNodeInfo>: Archive,
<Vec<JoinNodeInfo> as Archive>::Archived: Deserialize<Vec<JoinNodeInfo>, __D>,
Vec<u64>: Archive,
<Vec<u64> as Archive>::Archived: Deserialize<Vec<u64>, __D>,
Vec<JoinGroupInfo>: Archive,
<Vec<JoinGroupInfo> as Archive>::Archived: Deserialize<Vec<JoinGroupInfo>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<JoinResponse, __D> for Archived<JoinResponse>where
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Vec<JoinNodeInfo>: Archive,
<Vec<JoinNodeInfo> as Archive>::Archived: Deserialize<Vec<JoinNodeInfo>, __D>,
Vec<u64>: Archive,
<Vec<u64> as Archive>::Archived: Deserialize<Vec<u64>, __D>,
Vec<JoinGroupInfo>: Archive,
<Vec<JoinGroupInfo> as Archive>::Archived: Deserialize<Vec<JoinGroupInfo>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<JoinResponse, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<JoinResponse, <__D as Fallible>::Error>
Deserializes using the given deserializer