pub struct DataProposeRequest {
pub vshard_id: u32,
pub bytes: Vec<u8>,
}Expand description
Forward an opaque data-group proposal payload to the data-group leader.
vshard_id identifies the vShard (and thus the Raft group) the entry
belongs to. bytes is the serialized ReplicatedEntry.
Fields
vshard_id: u32bytes: Vec<u8>Trait Implementations
Sourceimpl Archive for DataProposeRequest
impl Archive for DataProposeRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDataProposeRequest
type Archived = ArchivedDataProposeRequest
The archived representation of this type. Read more
Sourcetype Resolver = DataProposeRequestResolver
type Resolver = DataProposeRequestResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for DataProposeRequest
impl Clone for DataProposeRequest
Sourcefn clone(&self) -> DataProposeRequest
fn clone(&self) -> DataProposeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataProposeRequest
impl Debug for DataProposeRequest
Sourceimpl<__D: Fallible + ?Sized> Deserialize<DataProposeRequest, __D> for Archived<DataProposeRequest>
impl<__D: Fallible + ?Sized> Deserialize<DataProposeRequest, __D> for Archived<DataProposeRequest>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<DataProposeRequest, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<DataProposeRequest, <__D as Fallible>::Error>
Deserializes using the given deserializer