pub struct ShufflePushEnd {
pub error: Option<TypedClusterError>,
}Expand description
Terminal frame of a shuffle push stream.
error: None is a clean EOF (all chunks delivered for this producer).
error: Some(e) is a terminal failure — any chunks already delivered are
valid, but this producer’s contribution is incomplete and the receiver must
surface the error. Mirrors
ExecuteStreamEnd.
Fields
error: Option<TypedClusterError>Trait Implementations
Sourceimpl Archive for ShufflePushEnd
impl Archive for ShufflePushEnd
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedShufflePushEnd
type Archived = ArchivedShufflePushEnd
The archived representation of this type. Read more
Sourcetype Resolver = ShufflePushEndResolver
type Resolver = ShufflePushEndResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ShufflePushEnd
impl Clone for ShufflePushEnd
Sourcefn clone(&self) -> ShufflePushEnd
fn clone(&self) -> ShufflePushEnd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShufflePushEnd
impl Debug for ShufflePushEnd
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShufflePushEnd, __D> for Archived<ShufflePushEnd>where
Option<TypedClusterError>: Archive,
<Option<TypedClusterError> as Archive>::Archived: Deserialize<Option<TypedClusterError>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ShufflePushEnd, __D> for Archived<ShufflePushEnd>where
Option<TypedClusterError>: Archive,
<Option<TypedClusterError> as Archive>::Archived: Deserialize<Option<TypedClusterError>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ShufflePushEnd, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ShufflePushEnd, <__D as Fallible>::Error>
Deserializes using the given deserializer