pub struct JoinGroupInfo {
pub group_id: u64,
pub leader: u64,
pub members: Vec<u64>,
pub learners: Vec<u64>,
}Expand description
Raft group membership in the join response wire format.
members are voting members; learners are non-voting catch-up peers
(see nodedb-raft learner semantics). A joining node that finds its
own id in learners creates the local Raft group in the Learner
role and waits for a subsequent PromoteLearner conf-change.
Fields
group_id: u64leader: u64members: Vec<u64>learners: Vec<u64>Trait Implementations
Sourceimpl Archive for JoinGroupInfo
impl Archive for JoinGroupInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedJoinGroupInfo
type Archived = ArchivedJoinGroupInfo
The archived representation of this type. Read more
Sourcetype Resolver = JoinGroupInfoResolver
type Resolver = JoinGroupInfoResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for JoinGroupInfo
impl Clone for JoinGroupInfo
Sourcefn clone(&self) -> JoinGroupInfo
fn clone(&self) -> JoinGroupInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JoinGroupInfo
impl Debug for JoinGroupInfo
Sourceimpl<__D: Fallible + ?Sized> Deserialize<JoinGroupInfo, __D> for Archived<JoinGroupInfo>
impl<__D: Fallible + ?Sized> Deserialize<JoinGroupInfo, __D> for Archived<JoinGroupInfo>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<JoinGroupInfo, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<JoinGroupInfo, <__D as Fallible>::Error>
Deserializes using the given deserializer