pub struct PongResponse {
pub responder_id: u64,
pub topology_version: u64,
}Expand description
Health check pong.
Fields
responder_id: u64topology_version: u64Trait Implementations
Sourceimpl Archive for PongResponse
impl Archive for PongResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPongResponse
type Archived = ArchivedPongResponse
The archived representation of this type. Read more
Sourcetype Resolver = PongResponseResolver
type Resolver = PongResponseResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for PongResponse
impl Clone for PongResponse
Sourcefn clone(&self) -> PongResponse
fn clone(&self) -> PongResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PongResponse
impl Debug for PongResponse
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PongResponse, __D> for Archived<PongResponse>
impl<__D: Fallible + ?Sized> Deserialize<PongResponse, __D> for Archived<PongResponse>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PongResponse, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PongResponse, <__D as Fallible>::Error>
Deserializes using the given deserializer