pub enum TopoError {
Cycle {
cycle: Vec<&'static str>,
},
UnknownDependency {
subsystem: &'static str,
dependency: &'static str,
},
}Expand description
Error produced during topo-sort of the subsystem dependency graph.
Variants
Cycle
A cycle was detected in the dependency graph.
cycle lists the subsystem names forming the cycle in order.
UnknownDependency
A subsystem listed a dependency that is not registered.