Write-path coordinator for distributed array operations.
Provides coord_put, coord_put_partitioned, and coord_delete
— functions that partition a flat cell/coord list by Hilbert tile and
fan writes to the owning vShards.
Structs
- Array
Write Coord Params - Parameters for write-path coordinator entry points (partitioned fan-out).
Functions
- coord_
delete - Partition a flat coord list by Hilbert tile and fan delete requests to owning shards.
- coord_
put - Partition a flat cell list by Hilbert tile and fan out to owning shards.
- coord_
put_ partitioned - Forward pre-partitioned cell writes to the owning shards.