pub fn handle_node_join(
node_id: u64,
addr: &str,
topology: &mut ClusterTopology,
) -> MetadataEntryExpand description
Register a joining node in the local topology and produce the
MetadataEntry to be proposed on the metadata Raft group.